import fetch from 'node-fetch';
export var HttpMethod;
(function (HttpMethod) {
    HttpMethod["Get"] = "get";
    HttpMethod["Post"] = "post";
    HttpMethod["Delete"] = "delete";
})(HttpMethod || (HttpMethod = {}));
export async function sendRequest({ url, method, body }) {
    const response = await fetch(url, {
        method,
        headers: {
            Accept: 'application/json',
            'Content-Type': 'application/json'
        },
        body: JSON.stringify(body)
    });
    let jsonResponse;
    try {
        jsonResponse = await response.json();
    }
    catch (error) {
        if (!response.ok) {
            throw new Error(response.statusText);
        }
    }
    if (response.ok) {
        return jsonResponse;
    }
    if (jsonResponse.data) {
        throw new Error(jsonResponse.data);
    }
    if (jsonResponse.detail) {
        throw new Error(jsonResponse.detail);
    }
    if (jsonResponse.message) {
        throw new Error(jsonResponse.message);
    }
    if (jsonResponse.nonFieldErrors) {
        throw new Error(jsonResponse.nonFieldErrors);
    }
    if (jsonResponse.delegate) {
        throw new Error(jsonResponse.delegate);
    }
    if (jsonResponse.safe) {
        throw new Error(jsonResponse.safe);
    }
    if (jsonResponse.delegator) {
        throw new Error(jsonResponse.delegator);
    }
    throw new Error(response.statusText);
}
//# sourceMappingURL=httpRequests.js.map